@@ -1,3 +1,3 @@
 TRAINING_PHASE = "train"
-EVALUATION_PHASE = "evaluation"
+EVALUATION_PHASE = "eval"
 PREDICTION_PHASE = "predict"
\ No newline at end of file
