@@ -7,7 +7,7 @@ from fintix_modelcurator.repository import ModelRepository
 
 
 def get_currenttime_ms():
-    return time.time() // 1_000_000
+    return time.time_ns() // 1_000_000
 
 
 def handle_error(error, logger=None):
@@ -38,4 +38,24 @@ def upload_model(model_name):
 
 
 def get_model_save_path(model_name):
-    return os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name)
+    return os.path.join(LOCAL_DEPLOY_MODEL_REPO, model_name, "saved_model")
+
+
+def log(msg=None, level=None):
+    if msg is None or msg == "":
+        return
+
+    loglevel = logging.DEBUG
+    if level == "info":
+        loglevel = logging.INFO
+
+    if level == "warn" or level == "warning":
+        loglevel = logging.WARNING
+
+    if level == "error":
+        loglevel = logging.ERROR
+
+    if level == "fatal" or level == "critical":
+        loglevel = logging.CRITICAL
+
+    logging.log(loglevel, msg)
\ No newline at end of file
